@@ -163,7 +163,6 @@ sub _search_limited_fields {
 sub _raw_search {
     my ($self, $ids_only, @args) = @_;
     ### Initial search args: @args
-    
     my @search;
     while (@args && ref $args[0] ne 'HASH') {push @search, shift @args}
     
@@ -192,7 +191,6 @@ sub _raw_search {
             }
         }
     }
-    
     my $context = $self->_get_context(shift @args);
     my $options = shift @args;
     $options = {} unless $options;
@@ -503,8 +501,10 @@ sub _collapse_data_to_ids
         if ($rel->{type} eq 'many2one') {
             if ($object_data->{$name}) {
                 $object_data->{$rel->{key}} = $self->_id($rel, $object_data->{$name});
-                delete $object_data->{$name} if $name ne $rel->{key};
-            }            
+            }
+            if ($name ne $rel->{key}) {
+                delete $object_data->{$name};
+            }
         }
         if ($rel->{type} eq 'many2many') {
             if ($object_data->{$name}) {
