@@ -1,19 +1,11 @@
 1;
 package OpenERP::OOM::Tutorial::Schema;
 
-__END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-OpenERP::OOM::Tutorial::Schema
-
-=head1 VERSION
-
-version 0.46
+OpenERP::OOM::Tutorial::Schema - Setting up an OpenERP::OOM Schema
 
 =head1 DESCRIPTION
 
@@ -117,21 +109,5 @@ Objects are created and retrieved from the class:
         say $partner->name;
     }
 
+
 __END__
-
-=head1 NAME
-
-OpenERP::OOM::Tutorial::Schema - Setting up an OpenERP::OOM Schema
-
-=head1 AUTHOR
-
-Jon Allen (JJ), <jj@opusvl.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011-2016 by OpusVL.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
